@@ -4,10 +4,10 @@ from nibiru_proto.proto.vpool.v1 import query_pb2_grpc as vpool_query
 from nibiru_proto.proto.vpool.v1.vpool_pb2 import Direction as pbDirection
 
 from nibiru.common import Direction
-from nibiru.query_clients.util import deserialize
+from nibiru.query_clients.util import QueryClient
 
 
-class VpoolQueryClient:
+class VpoolQueryClient(QueryClient):
     """
     VPool allows to query the endpoints made available by the Nibiru Chain's VPOOL module.
     """
@@ -17,11 +17,12 @@ class VpoolQueryClient:
 
     def reserve_assets(self, pair: str):
         req = vpool_type.QueryReserveAssetsRequest(pair=pair)
-        return deserialize(self.api.ReserveAssets(req))
+        return self.query(self.api.ReserveAssets, req)
 
     def all_pools(self):
         req = vpool_type.QueryAllPoolsRequest()
-        return deserialize(self.api.AllPools(req))
+        resp = self.query(self.api.AllPools, req)
+        return resp
 
     def base_asset_price(self, pair: str, direction: Direction, base_asset_amount: str):
         dir_pb = pbDirection.DIRECTION_UNSPECIFIED
@@ -33,4 +34,4 @@ class VpoolQueryClient:
         req = vpool_type.QueryBaseAssetPriceRequest(
             pair=pair, direction=dir_pb, base_asset_amount=base_asset_amount
         )
-        return deserialize(self.api.BaseAssetPrice(req))
+        return self.query(self.api.BaseAssetPrice, req)
